/****************************************************************************
*
*    Copyright (c) 2005 - 2018 by Vivante Corp.  All rights reserved.
*
*    The material in this file is confidential and contains trade secrets
*    of Vivante Corporation. This is proprietary information owned by
*    Vivante Corporation. No part of this work may be disclosed,
*    reproduced, copied, transmitted, or used in any way for any purpose,
*    without the express written permission of Vivante Corporation.
*
*****************************************************************************/


#ifndef __DRM_VIVANTE_H__
#define __DRM_VIVANTE_H__

#include <stdint.h>
#include <stdlib.h>
#include <vivante_drm.h>

#if defined(__cplusplus)
extern "C" {
#endif

struct drm_vivante_bo;
struct drm_vivante;

struct drm_vivante_bo_tiling {
    uint32_t tiling_mode;
    uint32_t ts_mode;
    uint64_t clear_value;
};

/* caller owns the driver fd. */
int drm_vivante_create(int fd, struct drm_vivante **drmp);
void drm_vivante_close(struct drm_vivante *drm);

int drm_vivante_bo_create(struct drm_vivante *drm,
            uint32_t flags, uint32_t size, struct drm_vivante_bo **bop);

/* create bo with auxillary tile-status bo. */
int drm_vivante_bo_create_with_ts(struct drm_vivante *drm,
            uint32_t flags, uint32_t size, struct drm_vivante_bo **bop);

/* caller owns the fd. */
int drm_vivante_bo_export_to_fd(struct drm_vivante_bo *bo, int *pfd);
/* caller still owns the fd upon return. */
int drm_vivante_bo_import_from_fd(struct drm_vivante *drm, int fd,
        struct drm_vivante_bo **bop);

void drm_vivante_bo_destroy(struct drm_vivante_bo *bo);

/* do not close the handle directly. */
int drm_vivante_bo_get_handle(struct drm_vivante_bo *bo, uint32_t *handle);

int drm_vivante_bo_mmap(struct drm_vivante_bo *bo, void **vaddr);
int drm_vivante_bo_munmap(struct drm_vivante_bo *bo);

int drm_vivante_bo_query(struct drm_vivante_bo *bo,
            uint32_t param, uint64_t *value);

int drm_vivante_bo_set_tiling(struct drm_vivante_bo *bo,
            const struct drm_vivante_bo_tiling *tiling);
int drm_vivante_bo_get_tiling(struct drm_vivante_bo *bo,
            struct drm_vivante_bo_tiling *tiling);

/* output inc'ed timestamp, optional. */
int drm_vivante_bo_inc_timestamp(struct drm_vivante_bo *bo,
            uint64_t *timestamp);
int drm_vivante_bo_get_timestamp(struct drm_vivante_bo *bo,
            uint64_t *timestamp);

int drm_vivante_bo_ref_node(struct drm_vivante_bo *bo,
            uint32_t *node, uint32_t *ts_node);

#if defined(__cplusplus)
}
#endif

#endif /* __DRM_VIVANTE_H__ */
